//*************+***************+***************+***************+***************+
//
//	SEKONIC
//	Device control header
//
//	FileName	: SkDvSr11000Api.h
//	CPU			: x86
//	Compiler	: Microsoft Visual C++ 2010
//
//*************+***************+***************+***************+***************+
//	2020.10.15	for SR-8000HYBRID
//	2012.08.10	for SR-11000
//*************+***************+***************+***************+***************+
#ifndef	INCLUDE_SKDVSR11000API_HEADER			// Multi include of a header is prevented.
#define	INCLUDE_SKDVSR11000API_HEADER

#pragma once

#include "SkDvSrSeriesPrm.h"
#include "SkDvSr11000Prm.h"
#include "SkDvSrOptionApi.h"



//*************+***************+***************+***************+***************+
#ifdef __cplusplus
extern "C" {
#endif



//*************+***************+***************+***************+***************+
//
// ID data management setting (layout definition start)
//
//		Set ID management settings for window control.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pLayManConf		Specify the pointer of the ID management structure for which the condition is set
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "ID management data setting [CMD: WM]" command to the OMR.
//		The ID management data setting command clears all OMR layout settings, 
//		and is set to recognize the window control layout ID such as the use / 
//		non-use of the form ID and the contents of the ID window.
//		When performing window control, it must be executed first, and finally "layout definition end" must be executed.
//		(It is necessary to execute before "ID data setting" and "Window area data setting".)
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetLayoutManage(SkDvHandle hSkDevice,
								SK_LAYOUT_MANAGE_CONF* pLayManConf);


//*************+***************+***************+***************+***************+
//
// Layout definition finished
//
//		Finish the window control layout settings (ID data settings, window area data settings).
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		piLimit			Specify a pointer to store the restricted state of continuous read operation
//						NULL can be specified. If NULL is specified, the restricted state is not stored.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "ID management data setting [CMD: WM]" command to the OMR. Finish the window control settings.
//		After executing this function, "ID data setting" and "Window area data setting" must not be executed.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetLayoutManageTerminate(SkDvHandle hSkDevice, int* piLimit);


//*************+***************+***************+***************+***************+
//
// ID data settings
//
//		Set the form ID and enable the window area to be set.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pLayIdConf		Specify the pointer of the ID data structure for which the condition is set
//		piIdIdx			Specify a pointer to store the 0-based ID number of the set ID data.
//						NULL can be specified. If NULL is specified, the set ID number will not be stored.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "ID data setting [CMD: WL]" command to the OMR.
//		Specify the ID pattern of the ID window area specified in "ID data management settings", 
//		and specify the number of timing marks on the form for that ID.
//		If the ID is not used in the "ID data management settings", 
//		the ID pattern in this function is ignored, but it must be called only once.
//		After executing this function, "window area data setting" of the ID can be performed.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetLayoutId(SkDvHandle hSkDevice,
								SK_LAYOUT_ID_CONF* pLayIdConf,
								int* piIdIdx);


//*************+***************+***************+***************+***************+
//
// Window area data settings
//
//		Set the window area of the form with the ID specified in "ID data setting".
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pWinAreaConf	Specify a pointer to the window area structure for which the condition is set
//		piWinIdx		Specify a pointer to store the window number starting from 0 in the set window area.
//						The window number is the entire number including all IDs.
//						NULL can be specified. If NULL is specified, the set window number will not be stored.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "Window area data setting [CMD: WD]" command to OMR.
//		It is set as the window area of the last "ID data setting".
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetWindowArea(SkDvHandle hSkDevice, 
								SK_WINDOW_AREA_CONF* pWinAreaConf,
								int* piWinIdx);


//*************+***************+***************+***************+***************+
//
// Clear layout settings
//
//		Clear all layout settings.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "Clear window information [CMD: WC]" command to OMR.
//		The contents of "ID data management settings", "ID data settings", and "window area data settings" are cleared.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqClearLayout(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
// Continuous reading fixed print character setting
//
//		Set fixed print characters for continuous reading.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pString			Specifies a pointer to a null-terminated string to be fixedly printed for continuous reading.
//						Up to 20 characters can be set
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "Printer Settings [CMD: PR]" command to OMR.
//		For font size, etc., use the setting / acquisition function of "Printer print conditions".
//		If the character string specified in the argument pString exceeds 20 characters, the excess is ignored.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetPrintFixString(SkDvHandle hSkDevice, char* pString);


//*************+***************+***************+***************+***************+
// Serial number print setting for continuous reading
//
//		Set serial number printing for continuous reading.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pPrnOpt			
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		
//		This function sends the "Printer Settings [CMD: PR]" command to OMR.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetContFeedPrint(SkDvHandle hSkDevice, SK_CONT_FEED_PRN_OPT* pPrnOpt);


//*************+***************+***************+***************+***************+
//
// Remote setting
//
//		The specified characters are displayed on the LCD of the OMR, and the operation with the panel switch is prohibited.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		blEnable		FALSE	:Invalid. The LCD and panel switches are controlled by OMR.
//						TRUE	:Effectiveness. The application controls the LCD and panel switches.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "Panel Remote Setting [CMD: PC]" command to OMR.
//		The LCD display of OMR disappears, but you can specify the LCD display contents with the "Panel display setting" function.
//		In addition, although the panel operation of OMR becomes impossible, 
//		the state of the panel switch can be acquired by acquiring the switch information instead.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetPanelUserEnable(SkDvHandle hSkDevice, BOOL blEnable);


//*************+***************+***************+***************+***************+
//
// Switch information acquisition
//
//		Acquires the status of the OMR panel switch.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pdwSwitch		Specify a pointer to store the state of the panel switch.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends the "Panel Remote Setting [CMD: PC]" command to OMR.
//		You can get the status of the panel switch when it is enabled by the "remote setting" function.
//		The latch information is the information of the panel switch pressed after the remote setting is enabled and the switch information is acquired.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetPanelUserSwitch(SkDvHandle hSkDevice, DWORD* pdwSwitch, DWORD* pdwSwitchLatch);


//*************+***************+***************+***************+***************+
//
//	Continuous reading printing Paper ejection instruction monitoring
//
//		Call the callback function for continuous read / print / output instructions
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		fnContFeedCallBack	Specify a callback function
//		lpParameter			Specify the value to pass to the callback function
//
//	Return value
//		TRUE	:Execute print discharge instruction
//		FALSE	:No processing
//
//	Remarks
//		By calling, when the mark data and barcode data have been received, 
//		the callback for the print / output instruction specified by the argument is called from this function.
//		In the callback function, it is necessary to write a code that determines the data and specifies the print / output instruction
//		Used when multithreading such as VB6.0 is not supported.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_PollingPrintEject(SkDvHandle hSkDevice, FN_SK_DV_CONTFEED_CALLBACK fnContFeedCallBack, LPVOID lpParameter);


//*************+***************+***************+***************+***************+
//
//	Continuous reading print printing output instruction callback function registration
//
//		Register the continuous read print output instruction callback function
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		fnContFeedCallBack	Specify a callback function
//		lpParameter			Specify the value to pass to the callback function
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail
//
//	Remarks
//		Register a function that will be called when data is received from OMR.
//		In the callback function, it is necessary to write a code that determines the data and specifies the print / output instruction.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_RegistPrintEjectCallback(SkDvHandle hSkDevice, FN_SK_DV_CONTFEED_CALLBACK fnContFeedCallBack, LPVOID lpParameter);


//*************+***************+***************+***************+***************+
//
//	Continuous reading mark data acquisition
//
//		Acquire mark data for judging print / discharge instructions by continuous reading
//
//	Parameters
//		See 'SkDv_GetContDataMarks' function
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail
//
//	Remarks
//		Printed output instruction Can be used only in the callback function
//		See 'SkDv_GetContDataMarks' function
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataMarks_Now(SkDvHandle hSkDevice, int iFace, SK_DV_MARK_INFO *pMarkResult, 
								char* pMarks, int* piBufSize);


//*************+***************+***************+***************+***************+
//
// Acquisition of continuous read barcode data (number of reads)
//
//		Acquire the number of barcodes for judging the print / discharge instruction by continuous reading.
//
//	Parameters
//		See 'SkDv_GetContDataBarcodesCount' function
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail
//
//	Remarks
//		Printed output instruction Can be used only in the callback function
//		See 'SkDv_GetContDataBarcodesCount' function
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataBarcodesCount_Now(SkDvHandle hSkDevice, 
								int* piReadCount);


//*************+***************+***************+***************+***************+
//
// Acquisition of continuous read barcode data (data)
//
//		Acquires the data of the number specified by the barcode for judging the print / discharge instruction by continuous reading.
//
//	Parameters
//		See 'SkDv_GetContDataBarcodesData' function
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail
//
//	Remarks
//		Printed output instruction Can be used only in the callback function
//		See 'SkDv_GetContDataBarcodesData' function
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataBarcodesData_Now(SkDvHandle hSkDevice, 
								int iIndex, char* pcBcType, char* pszBarcode, int* piDataLen);

//*************+***************+***************+***************+***************+
//
//	Continuous feed request
//
//		Start continuous reading.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		dwReqData		Specify the data output method
//						Normally, specify SKDV_CONT_FEED_REQ_NORMAL.
//						See 'SkDvSr11000Prm.h - [SkDv_ReqContFeedSheet - dwReqData]'
//		iErrReject		Specify whether to reject when an error occurs.
//						SKDV_DISABLE (0): Main output / SKDV_ENABLE (1): Select output (reject)
//						The error here is timing mark error / DF error / leftmost skew error
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Send the "Sheet continuous read [CMD: CF]" command to the OMR to start continuous read.
//		This function internally creates a worker thread, automatically receives mark data, etc., and automatically terminates 
//		the worker thread when all readings are completed (including error stop).
//		The operation status of the worker thread can be confirmed by "Confirmation during continuous read operation".
//		While the worker thread is running, do not call any function that communicates with OMR other than a "continuous read cancel request".
//		The functions that the worker thread may use while running are as follows.
//			* Continuous read cancellation request
//			* Check during continuous reading operation
//			* Confirmation of the end of continuous reading data
//			* Continuous read unacquired data confirmation
//			* Continuous reading Read status (number of sheets) acquisition
//			* Continuous read data preparation
//			* Continuous read data Get current data number
//			* Continuous reading mark data acquisition
//			* Continuous reading barcode data acquisition
//			* Continuous reading barcode data acquisition (number)
//			* Continuous reading barcode data acquisition (data)
//			* Continuous reading form reading result acquisition
//			* Acquisition of continuous reading results
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqContFeedSheet(SkDvHandle hSkDevice, DWORD dwReqData, int iErrReject);


//*************+***************+***************+***************+***************+
//
//	Continuous read cancel request
//
//		Cancel the continuous read operation.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		This function sends a "cancel operation [CMD: CA]" command to OMR, 
//		instructing OMR to suspend continuous reading.
//		Even if control returns from this function, continuous reading does not necessarily end.
//		The operation status can be confirmed by "SkDv_IsContFeedRunning".
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqContFeed_Cancel(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Confirmation during continuous reading operation
//
//		Check if continuous reading is working.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		You can check whether the worker thread executed by the "Continuous read request" function is running.
//		Note that the worker thread does not end immediately even if the "Continuous read cancel request" function is executed.
//
//*************+***************+***************+***************+***************+
BOOL	WINAPI	SkDv_IsContFeedRunning(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Confirmation of end of continuous read data
//
//		Check if the continuous read started by the "Continuous read request" function is completed and there is no data.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//
//	Return value
//		TRUE	:The continuous read thread is running.
//		FALSE	:The continuous read thread has terminated.
//
//	Remarks
//		It can be confirmed whether the worker thread executed by the "continuous read request" function has ended 
//		and all the read data has been acquired by the "continuous read data preparation" function.
//		This function returns TRUE when the worker thread of continuous reading is terminated 
//		by the "confirmation during continuous reading operation" function and all the data is lost 
//		by the "confirmation of unacquired continuous reading data" function.
//
//*************+***************+***************+***************+***************+
BOOL	WINAPI	SkDv_IsContFeedDataFinished(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Confirmation of unacquired data for continuous reading
//
//		Check if the continuous read data started by the "Continuous read request" function is accumulated.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		It is possible to confirm whether the continuous read data accumulated by the worker thread executed 
//		by the "continuous read request" function exists in this library.
//		Note that it may return FALSE if the continuous read worker thread is running but the continuous read data has not yet been accumulated.
//
//*************+***************+***************+***************+***************+
BOOL	WINAPI	SkDv_ExistDoneData(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Continuous reading Read status (number of sheets) acquisition
//
//		Gets the current number status received by the continuous read worker thread.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pContFeedCount	Specify the pointer of the continuous read number structure to store the current number status.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Acquires the current number of worker threads executed by the "Continuous read request" function.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetContFeedCount(SkDvHandle hSkDevice, SK_CONT_FEED_COUNT* pContFeedCount);


//*************+***************+***************+***************+***************+
//
//	Continuous read data preparation
//
//		Prepare to retrieve the data received by the continuous read worker thread.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//
//	Return value
//		Status code (SkDvStatus)
//		In the continuous reading operation, the status when actually reading one form is returned.
//
//	Remarks
//		By executing this function, the continuous read worker thread prepares to acquire the received data.
//		If the continuous read data has not been accumulated yet, it waits in this function until the worker thread receives the data.
//		The waiting time varies depending on the situation, but it may take more than 10 seconds, 
//		so if you do not want to stop the processing, check that there is data accumulated 
//		by the "Continuous read unacquired data confirmation" function before reading the book.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_PrepareContData(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Continuous read data Get current data number
//
//		Get the current data number (number of sheets) of continuous read data
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//
//	Return value
//		the current data number (number of sheets)
//
//	Remarks
//		If this function is executed immediately after executing the "Continuous read request" function, the return value will be 0.
//		After that, each time "Continuous read data preparation" is executed, 
//		the data is incremented by one, and the number of actually read data is increased to +1.
//
//*************+***************+***************+***************+***************+
int			WINAPI	SkDv_GetContDataNumber(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	Continuous reading mark data acquisition
//
//		Get the mark data prepared by continuous read data preparation
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		iFace			Specify whether it is the front side or the back side.
//		pMarkInfo		Specify the address of the structure for storing the mark information.
//						See "SK_DV_MARK_INFO" for the contents of the structure.
//		pMarks			Specify the address of the buffer for storing the mark data.
//						The mark density is stored from 0 to 16 for each byte.
//						If NULL is specified, mark data will not be stored.
//		piBufSize		Specifies the byte size of the buffer for storing mark data.
//						Stores data in the buffer specified by pMarks up to the specified size.
//						After executing the process, the required buffer size is stored.
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//		Get the mark data prepared by the "Continuous read data preparation" function.
//		The content of the argument is the same as the SkDv_ReqGetMarks function.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataMarks(SkDvHandle hSkDevice, int iFace, SK_DV_MARK_INFO *pMarkResult, 
								char* pMarks, int* piBufSize);


//*************+***************+***************+***************+***************+
//
//	Continuous reading barcode data acquisition
//
//		Get the barcode data prepared by continuous read data preparation
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		pBarcodeResult	Specify the address of the structure for storing barcode information.
//		pBarcodes		Specify the address of the buffer for storing barcode data.
//						Barcode data is lined up by type / number of bytes of data / number of data read.
//		piBufSize		Specifies the byte size of the buffer for storing barcode data.
//						Stores data in the buffer specified by pBarcodes up to the specified size.
//						After executing the process, the required buffer size is stored.
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//		Get the barcode data prepared by the "Continuous read data preparation" function.
//		Since the barcode data is lined up by type / number of bytes of data / number of times 
//		the data is read and separated by commas, it is necessary to analyze the data.
//		When processing each piece of data, the number of barcodes read 
//		by the SkDv_GetContDataBarcodesCount function is acquired, 
//		and each piece of barcode data is acquired by the SkDv_GetContDataBarcodesData function.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataBarcodes(SkDvHandle hSkDevice, SK_DV_BARCODE_RESULT *pBarcodeResult, 
								char* pBarcodes, int* piBufSize);


//*************+***************+***************+***************+***************+
//
// Acquisition of continuous read barcode data (number of reads)
//
//		Get the number of barcodes read prepared by continuous read data preparation
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		piReadCount		Specify the address of the variable to store the number of barcodes read.
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//		Gets the number of barcodes read by the "Continuous Read Data Preparation" function.
//		Same as 'pBarcodeResult->iCount' which can be obtained by "SkDv_GetContDataBarcodes" function.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataBarcodesCount(SkDvHandle hSkDevice, 
								int* piReadCount);


//*************+***************+***************+***************+***************+
//
// Acquisition of continuous read barcode data (data)
//
//		Acquires the data of the specified number of the read barcode prepared in the continuous read data preparation.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		iIndex			Specify the index number of the read barcode starting from 1.
//		pcBcType		Specify the pointer of the variable to store the barcode type specified by iIndex.
//		pszBarcode		Specify the address of the buffer for storing the barcode data specified by iIndex.
//		piDataLen		Specify the byte size of the buffer for storing the barcode data specified by iIndex.
//						Stores data in the buffer specified by pszBarcode up to the specified size.
//						After executing the process, the required buffer size is stored.
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//		Acquires the data of the specified number of the barcode prepared by the "Continuous read data preparation" function.
//		It is the result of decomposing the barcode data that can be acquired by the SkDv_GetContDataBarcodes function one by one.
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataBarcodesData(SkDvHandle hSkDevice, 
								int iIndex, char* pcBcType, char* pszBarcode, int* piDataLen);


//*************+***************+***************+***************+***************+
//
// Save image file for continuous reading
//
//		Save the scanned Jpeg image prepared in continuous read data preparation to a file
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		iFace			Specify the face to save. SKDV_FRONT (0): Front / SKDV_BACK (1): Back
//		pszFilename		Specify the file name to save.
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_SaveContJpegImage(SkDvHandle hSkDevice, int iFace, char* pszFilename);


//*************+***************+***************+***************+***************+
//
//	Continuous reading form reading result acquisition
//
//		Acquire the form reading result prepared by continuous reading data preparation
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		pSheetResult	Specify the pointer of the structure that stores the form reading result
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContDataSheetResult(SkDvHandle hSkDevice, SK_SHEET_RESULT *pSheetResult);


//*************+***************+***************+***************+***************+
//
//	Acquisition of continuous reading results
//
//		Acquisition of continuous reading results
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.B
//		pContFeedResult	Specify the pointer of the structure that stores the continuous reading result
//
//	Return value
//		TRUE	:Success
//		FALSE	:Fail (when there is an error in the argument or there is no data)
//
//	Remarks
//
//*************+***************+***************+***************+***************+
BOOL		WINAPI	SkDv_GetContFeedResult(SkDvHandle hSkDevice, SK_CONT_FEED_RESULT *pContFeedResult);


#ifdef __cplusplus
}
#endif

#endif											// Multi include of a header is prevented.

