//*************+***************+***************+***************+***************+
//
//	SEKONIC
//	Device control header
//
//	FileName	: SkDvSr3500Api.h
//	CPU			: x86
//	Compiler	: Microsoft Visual C++ 2010
//
//*************+***************+***************+***************+***************+
//	2011.10.27	for SR-3500 HYBRID
//*************+***************+***************+***************+***************+
#ifndef	INCLUDE_SKDVSR3500IMGAPI_HEADER			// Multi include of a header is prevented.
#define	INCLUDE_SKDVSR3500IMGAPI_HEADER

#pragma once

#include "SkDvSrSeriesPrm.h"


//*************+***************+***************+***************+***************+
#ifdef __cplusplus
extern "C" {
#endif


//*************+***************+***************+***************+***************+
//
//	SkDv_GetImageConf
//
//		Settling Operating condition for Image reading into Library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pDvImageConf	Appointing the address of Structure to fold Operating condition for Mark reading
//						Structure description can be referred at "SK_DV_SR3500IMG_CONF".
//		pDvImageConfEx	Appointing the address of Structure to fold Operating condition for Image reading
//						Structure description can be referred at "SK_DV_IMAGE_CONF_EX".
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Operating condition for Image reading to get is saved in this Library. 
//		Operating condition for Image reading is folded in Parameter "pDvMarkConf".
//		Communication with Device is not done.
//		If you would like to get description settled in Device right after starting,
//		Please call Function "SkDv_ReqInit" or "SkDv_ReqGetImageConf".
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetImageConf(SkDvHandle hSkDevice, SK_DV_SR3500IMG_CONF* pDvImageConf);

SkDvStatus	WINAPI	SkDv_GetImageConfEx(SkDvHandle hSkDevice, SK_DV_IMAGE_CONF_EX* pDvImageConfEx);


//*************+***************+***************+***************+***************+
//
//	SkDv_SetImageConf
//
//		Settling Operating condition for Image reading into Library.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pDvImageConf	Appointing the address of Structure to fold Operating condition for Image reading
//						Structure description can be referred at "SK_DV_SR3500IMG_CONF".
//		pDvImageConfEx	Appointing the address of Structure to fold Operating condition for Image reading
//						Structure description can be referred at "SK_DV_IMAGE_CONF_EX".
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		If getting Device info. has not been done, you can communicate 
//		with Device and fold the Device info. into library. 
//		Operation mode for Image reading appointed at Parameter "pDvImageConf" 
//		is checked as referring to Device info's description, 
//		and if the value has any problems, Error is returned.
//		If there is no error, Operation mode is folded into Library.
//		Setting description of Operation mode for Mark reading can be settle into Device 
//		by executing "Demand for Reading" or Function "SkDv_ReqImageConf" via communication.
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SetImageConf(SkDvHandle hSkDevice, SK_DV_SR3500IMG_CONF* pDvImageConf);

SkDvStatus	WINAPI	SkDv_SetImageConfEx(SkDvHandle hSkDevice, SK_DV_IMAGE_CONF_EX* pDvImageConfEx);


//*************+***************+***************+***************+***************+
//
//	SkDv_ReqScanForm
//
//		Reading Mark sheet, and capturing Image data.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Reading Mark sheet by Command "NS"
//		If the communication for getting Image/setting Condition/CIS standard data has not been done, 
//		the communication will be done before Reading.
//		Reading sheet and folding Image data into this library.
//		This function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqScanForm(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	SkDv_GetFormSize
//
//		Getting the info of sheet size
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pSizeForm		Appointing the address of Structure to fold the size of sheet. 
//						The measure of value is 0.1mm.
//						Structure SIZE can be referred at "MFC Library reference"
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Getting the sheet size from Image data in Middleware.
//		Width"cx" is the maximum width which Device can read, 
//		and Length"cy" is the length which Device has detected by sensor. 
//		Above "Image data in Middleware" means Image data captured by "SkDv_ReqScanForm" Function.
//		This function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetFormSize(SkDvHandle hSkDevice, SIZE* pSizeForm);

SkDvStatus	WINAPI	SkDv_GetFormSizeFace(SkDvHandle hSkDevice, SIZE* pSizeForm, int iFace);

//*************+***************+***************+***************+***************+
//
//	SkDv_SetImageElongationDetectInfo #011
//
//		Detects the elongation of the scanned image
//
//	Parameters
//		hSkDevice			Appointing Device controlling handle.
//		pElongationInfo		Appointing the address of the structure to enter information for
//							detecting the elongation of the image.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Detects image elongation from image data in middleware.
//		The above "image data in middleware" means image data acquired by the "SkDv_ReqScanForm" function.
//		For "blEnabled", specify whether or not to perform image decompression detection after image reading.
//		For "SheetLen", specify the length of the sheet to be used in units of 0.1 mm. (Min:110, Max:355.6)
//		For "threshold", designate the maximum length which is not judged that the image is stretched. (10mm, 20mm, 30mm)
//		In threshold, a threshold value for performing image extension detection is stored.
//		This Command is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SetImageElongationDetectInfo(SkDvHandle hSkDevice, SK_DV_IMG_ELGT_DETECT_CONF* pElongationInfo);


//*************+***************+***************+***************+***************+
//
//	SkDv_GetImageElongationDetectInfo #011
//
//		Information for detecting the elongation of the image is acquired.
//
//  Parameters
//		hSkDevice			Appointing Device controlling handle.
//		pElongationInfo		Appointing the address of the structure to enter information for
//							detecting the elongation of the image.
//
//  Return value
//		Status code (SkDvStatus)
//
//  Remarks
//		Retrieves image extension detection information set by SkDv_SetImageElongationDetectInfo.
//		In blEnabled, a boolean value indicating whether image extension detection is performed or not is stored.
//		In SheetLen, the length of the form to be subjected to image elongation detection is stored.
//		In threshold, a threshold value for performing image extension detection is stored.
//		This Command is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_GetImageElongationDetectInfo(SkDvHandle hSkDevice, SK_DV_IMG_ELGT_DETECT_CONF* pElongationInfo);


//*************+***************+***************+***************+***************+
//
//	SkDv_SaveImageData
//
//		Saving Image data appointed.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pImageDataConf	Appointing the address of Structure which appointed 
//						the Image data getting condition. 
//						The content of Structure can be referred at "SK_DV_IMAGE_DATA_CONF"
//
//		pImageFileConf	Appointing the address of Structure which appointed the File form to save.
//						The content of Structure can be referred at "SK_DV_IMAGE_FILE_CONF"
//
//		pszFilename		Appointing the address of character string which folds Name of File to save.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Saving the Image data in this library into File.
//		Above "Image data in Middleware" means Image data captured by "SkDv_ReqScanForm" Function.
//		In case saving is executed in resolution high than image, 
//		the quality of Image is to be rough than to saving is executed.  
//		And in case saving is Color but the image is grayscale, saved image is to be Grayscale.
//		As for File name of these image file, it's required to check overwrite or forbidden words 
//		in advance before call this function.
//		This Command is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SaveImageData(SkDvHandle hSkDevice, 
								SK_DV_IMAGE_DATA_CONF* pImageDataConf, 
								SK_DV_IMAGE_FILE_CONF* pImageFileConf, char* pszFilename);



//*************+***************+***************+***************+***************+
//
//	FN_SK_DV_SAVEIMAGE_CALLBACK
//
//		Call Back function for Saving the Image Data by other Threads
//
//	Parameters
//		pImageDataConf	Appoint address of Structure which Appoints the setting of condition for the folding Image Data
//		pImageFileConf	Appoint Address of the structure to appoint the saving extension (Format) 
//		pszFilename		Pointer which folded the image file name.
//		Status			Folded Status code to be saved the image data files by other threads.
//		lpParameter		Folded the user parameter which appointed SkDv_SaveImageDataThread
//
//	Return value
//		TRUE	:Saving the Image Data at other threads by the following setting
//		FALSE	:Finish the saving Image Data by other Threads.
//
//	Remarks
//		This function is to set into User Application to receive the result Data of File Saving 
//		by "SkDv_SaveImageDataThread" function. 
//		It would be better to add the error processing because Parameter "Status" folds the status code 
//		of results saving Image Data in other threads. 
//		Return "True" to save the Image Data Files by Parameter 
//		"pImageDataConf" "pImageFileConf" "pszFilename" (need change these contents), 
//		Return "FALSE" to end other threads to save the file.
//
//*************+***************+***************+***************+***************+
#ifndef FN_SK_DV_SAVEIMAGE_CALLBACK_DEFINE
#define FN_SK_DV_SAVEIMAGE_CALLBACK_DEFINE
typedef BOOL (CALLBACK *FN_SK_DV_SAVEIMAGE_CALLBACK)(SK_DV_IMAGE_DATA_CONF* pImageDataConf, SK_DV_IMAGE_FILE_CONF* pImageFileConf, char* pszFilename, SkDvStatus Status, LPVOID lpParameter);
#endif


//*************+***************+***************+***************+***************+
//
//	SkDv_SaveImageDataThread
//
//		Saving the appointed Image data by other threads
//
//	Parameters
//		hSkDevice			Appointing Device controlling handle.
//		pImageDataConf		Appoint the address of structure which appointed the setting condition of Image Data
//							See "SK_DV_IMAGE_DATA_CONF" refer for the contents of structure.
//
//		pImageFileConf		Appoint the address of structure which appoints the file type to be saved.
//							See "SK_DV_IMAGE_FILE_CONF" refer for the contents of structure.
//
//		pszFilename			Appoint the address of structure which appoints the name of save name
//		fnSaveImageCallback	Appointing the pointer of Callback functions after finish Image Data saving. 
//							Not callback acceptable while "NULL"
//
//		lpParameter			User Parameter hand over for Callback function
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Save the Image file which is keep in this library to the other Threads. 
//		The Function of "SkDv_SaveImageDataThread" would be finish prior to file saved completely. 
//		It can be operated by separated Threads for save Image Data (Front and Back side), 
//		but Data is holding in this API function in case not finished the previous Threads. 
//		Parameters "SkDv_SaveImageData" and "SkDv_CreateImage" can not save the Image Data 
//		until the following reading start in case execute this function.
//		The Contents to be saved file is same as while use function of "SkDv_SaveImageData"
//
//		No Callback executed while Parameter "fnSaveImageCallback"is "NULL".
//		Then No information while save incorrectly. 
//		That's why, User application should have function to detect whether file saved correctly. 
//		Function "SkDv_CreateImage" has function to be judgment saved file is actuary made or not saved yet.
//		It can be received the Error Status by the Parameter 
//		in case set the callback function in Parameter "fnSaveImageCallback"
//		See "FN_SK_DV_SAVEIMAGE_CALLBACK" for the reference of callback.
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_SaveImageDataThread(SkDvHandle hSkDevice, 
								SK_DV_IMAGE_DATA_CONF* pImageDataConf, 
								SK_DV_IMAGE_FILE_CONF* pImageFileConf, char* pszFilename,
								FN_SK_DV_SAVEIMAGE_CALLBACK fnSaveImageCallback, LPVOID lpParameter);


//*************+***************+***************+***************+***************+
//
// SkDv_IsThreadRunning
//
//		Confirm Threads created by "SkDv_SaveImageDataThread" function has closed.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		TRUE	:Thread running saving image data files.
//		FALSE	:All threads have finished saving the image data files.
//
//	Remarks
//		Possibility to confirm other Threads (to be save Image files) made by the function 
//		of SkDv_SaveImageDataThread" has closed.
//		Recommend to use this function in case use the function"SkDv_SaveImageDataThread"without callback.
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
BOOL	WINAPI	SkDv_IsThreadRunning(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	SkDv_CreateImage
//
//		Generating Image data in appointed range.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pImageDataConf	Appointing the address of Structure which appointed the Image data getting condition. 
//						The content of Structure can be referred at "SK_DV_IMAGE_DATA_CONF"
//		ppBitmapBits	Appointing the address to get the address folding the bit data of Image data.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Securing the memories folding Image data, and to return the address folding Image data in this library.
//		As the memories are secured in this Function, you have to release the memories at "SkDv_DestroyImage" 
//		However, not able to get Image data unless executing "Demand for Reading".
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_CreateImage(SkDvHandle hSkDevice, 
								SK_DV_IMAGE_DATA_CONF* pImageDataConf, 
								void** ppBitmapBits);


//*************+***************+***************+***************+***************+
//
//	SkDv_DestroyImage
//
//		Destroying the Image data generated at "SkDv_CreateImage"
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//		pBitmapBits		Appointing the address folding the bit data gained at "SkDv_CreateImage".
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Releasing the memories secured at "SkDv_CreateImage"
//		However, Image data cannot be saved unless executing "Demand for Reading".
//		This Function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_DestroyImage(SkDvHandle hSkDevice, void* pBitmapBits);


//*************+***************+***************+***************+***************+
//
//	SkDv_ReqGetImageConf
//
//		Communicating to get Image condition from Device.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Communicating to get Image condition, to save it into Library/
//		Using command is as following.
//		- Setting command for Image reading "IR"
//		This Command is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetImageConf(SkDvHandle hSkDevice);


//*************+***************+***************+***************+***************+
//
//	SkDv_ReqSetImageConf
//
//		Communicating to settle Image condition into Device.
//
//	Parameters
//		hSkDevice		Appointing Device controlling handle.
//
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Settling the Image condition in Library into Device.
//		Using command is as same as "SkDv_ReqGetImageConf" Function.
//		This Command is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetImageConf(SkDvHandle hSkDevice);

//*************+***************+***************+***************+***************+//#004
//
//	SkDv_ReqGetImgReadSheetLength
//
//		Get Device image reading sheet length infomation by communication.
//
//	Parameters
//		hSkDevice			Appointing Device controlling handle.
//		pImgReadSheetLen	Please set the address of the variable for storing 
//							the image reading sheet length information.
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Use request command for Set Image Reading Sheet Length "IL", to get Length infomation. 
//		Image reading sheet length information are folded in " pImageReadingSheetLength ".
//		This function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqGetImgReadSheetLength(SkDvHandle hSkDevice,int* pImgReadSheetLen);

//*************+***************+***************+***************+***************+//#004
//
//	SkDv_ReqSetImgReadSheetLength
//
//		Set Device image reading sheet length infomation by communication.
//
//	Parameters
//		hSkDevice			Appointing Device controlling handle.
//		ImgReadSheetLen	Please set the variable for storing  
//							the image reading sheet length information.
//	Return value
//		Status code (SkDvStatus)
//
//	Remarks
//		Use request command for Get Image Reading Sheet Length "IL", to set Length infomation.  
//		If the sheet length exceeds the specified size is read, 
//		the image reading length is up to specified size.
//		This function is only for Image reader equipment, not use for without Image reader.
//
//*************+***************+***************+***************+***************+
SkDvStatus	WINAPI	SkDv_ReqSetImgReadSheetLength(SkDvHandle hSkDevice,int ImgReadSheetLen);


#ifdef __cplusplus
}
#endif

#endif											// Multi include of a header is prevented.
