Option Explicit On
Imports System.Runtime.InteropServices
Imports System.Text.Encoding

Public Class OMRAPI_Sample

    '=========================================================
    '	Sample Program Start
    '=========================================================

    '//
    '// Main [Mark Only(+ Option)]
    '//
    '//////////////////////////////////////////////////////////////////////////////
    Private Sub B_MARK_ONLY_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles B_MARK_ONLY.Click
        Dim dwStatus As OMR_STATUS                          '// Return value
        Dim dwDeviceInfo As UInteger                        '// Parameter to store the Device information
        Dim nDevice As Integer                              '// Parameter to store the information OMR Device is open

        Dim nColumns As Long                                '// Setting value of reading row
        Dim nControlType As Long                            '// Setting value of reading method
        Dim nMultipleValue As Long                          '// Setting value of Magnification while set "Control" on the reading method
        Dim nDirective As Long                              '// Setting value of backside reading
        Dim nThickness As Long                              '// Setting value of paper thickness
        Dim dwConfigData As UInteger                        '// Setting value of warning Error
        Dim nSkewCol As Long                                '// Setting value of mark skew detection
        Dim nSkewLevel As Long                              '// Setting value of mark skew detection level
        Dim nPanelEnable As Long                            '// Setting value of the panel operation
        Dim nVolume As Long                                 '// Setting value of the buzzer loudness
        Dim nTone As Long                                   '// Setting value of the buzzer tone
        Dim pID(20) As Byte                                 '// Setting value of the Device ID
        Dim bytMarks(SR_COL_MAX * SR_ROW_MAX) As Byte       '// Buffer to store Mark data

        Dim bResponse As Boolean                            '// Return value OMRAPI function
        Dim bBarcodeCheck As Boolean                        '// Flag barcode operation
        Dim sBcType(SR_BARCODE_NUMBER_MAX) As Byte          '// Pointer to store the Barcode type(1byte)
        Dim sBcData(64, 256) As Byte                        '// Pointer to store the Barcode Data
        Dim nBcDataLen(SR_BARCODE_NUMBER_MAX) As Integer    '// Pointer to store the bytes of barcode data
        Dim nReadCount As Integer = 0                       '// Pointer to store the number of Barcode set the reading area
        Dim nSettingCount As Integer = 0                    '// Pointer to store the barcode data
        Dim BarcodeArea(10) As OMR_BARCODE_AREA             '// Structure condition of Area of Barcode

        Dim bPrintCheck As Boolean                          '// Flag Printer Operation

        Dim strFolderPath As String = Nothing               '// Fullpath executed file
        Dim strTime As String = Nothing                     '// Current time
        Dim strTextBuffer As String                         '// TXT buffer

        Dim MarkInfo As OMR_MARK_INFO                       '// Structure store Mark Information

        '//--------------------------------------------------------
        '//  Get User setting
        '//--------------------------------------------------------

        '// If checked "Print", 
        bPrintCheck = IIf(True = Me.CHECK_PRINT.Checked, True, False)

        '// If checked "Read Barcode",
        bBarcodeCheck = IIf(True = Me.CHECK_BARCODE.Checked, True, False)

        '//--------------------------------------------------------
        '//  Initialization
        '//--------------------------------------------------------

        '// Open Device
        dwStatus = OMR_OpenDeviceUSB()
        If (OMR_STATUS.SR_SUCCESS = dwStatus) Then
            nDevice = 1
        Else
            Call ErrorMessage("OMR_OpenDeviceUSB", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Initialize Device
        '// Hold OMR setting into library
        bResponse = OMR_InitialSetting()
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_InitialSetting", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the information of OMR unit
        dwDeviceInfo = OMR_GetDeviceInfo()
        If (SR_FUNCTION_FAIL = dwDeviceInfo) Then
            Call ErrorMessage("OMR_GetDeviceInfo", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '//--------------------------------------------------------
        '//  Set mark reading
        '//--------------------------------------------------------

        '// Get the setting of reading row
        '// (Windows API manual 6.4.2.)
        nColumns = OMR_GetNumberOfColumnsToRead()
        If (0 = nColumns) Then
            Call ErrorMessage("OMR_GetNumberOfColumnsToRead", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the setting of Reading method
        '// (Windows API manual 6.4.4.)
        bResponse = OMR_GetReadingMethod(nControlType, nMultipleValue)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_GetReadingMethod", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the setting of paper thickness
        '// (Windows API manual 6.4.8.)
        nThickness = OMR_GetSheetThickness()
        If (SR_FUNCTION_FAIL = nThickness) Then
            Call ErrorMessage("OMR_GetSheetThickness", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the setting of warning Error
        '// (Windows API manual 6.4.10.)
        bResponse = OMR_GetWarningError(dwConfigData, nSkewCol, nSkewLevel)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_GetWarningError", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the setting of Panel operation
        '// (Windows API manual 6.4.12.)
        nPanelEnable = OMR_GetPanelConfig()
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_GetPanelConfig", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the buzzer operation
        '// (Windows API manual 6.4.14.)
        bResponse = OMR_GetBuzzerConfig(nVolume, nTone)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_GetBuzzerConfig", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Get the Device ID
        '// (Windows API manual 6.4.16.)
        bResponse = OMR_GetID(pID(0))
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_GetID", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the reading row
        '// (Windows API manual 6.4.1.)
        bResponse = OMR_SetNumberOfColumnsToRead(nColumns)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetNumberOfColumnsToRead", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the reading method
        '// (Windows API manual 6.4.3.)
        bResponse = OMR_SetReadingMethod(nControlType, nMultipleValue)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetReadingMethod", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the backside reading
        '// (Windows API manual 6.4.5.)
        nDirective = SR_ENABLE
        bResponse = OMR_SetBackSensorUnit(nDirective)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetBackSensorUnit", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the paper thickness
        '// (Windows API manual 6.4.7.)
        bResponse = OMR_SetSheetThickness(nThickness)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetSheetThickness", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the condition of Warning Error
        '// (Windows API manual 6.4.9.)
        nSkewCol = 1
        nSkewLevel = 1
        bResponse = OMR_SetWarningError(dwConfigData, nSkewCol, nSkewLevel)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetWarningError", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set panel operation
        '// (Windows API manual 6.4.11.)
        bResponse = OMR_SetPanelConfig(nPanelEnable)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetPanelConfig", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set buzzer operation
        '// (Windows API manual 6.4.13.)
        bResponse = OMR_SetBuzzerConfig(nVolume, nTone)
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetBuzzerConfig", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '// Set the Device ID
        '// (Windows API manual 6.4.15.)
        bResponse = OMR_SetID(pID(0))
        If (True <> bResponse) Then
            Call ErrorMessage("OMR_SetID", CLng(OMR_GetLastError()))
            GoTo Termination
        End If

        '//--------------------------------------------------------
        '//  Barcode setting
        '//--------------------------------------------------------

        ''// If check [Read Barcode], then execute barcode unit
        If (True = bBarcodeCheck) Then

            '// Barcode unit would activate in case Barcode unit connected
            If ((SR_DEVICE_UNIT_BARCODE_V <> (dwDeviceInfo And SR_DEVICE_UNIT_BARCODE_MASK)) And _
                    (SR_DEVICE_UNIT_BARCODE_H <> (dwDeviceInfo And SR_DEVICE_UNIT_BARCODE_MASK))) Then
                MessageBox.Show("Barcode unit unconnected", "OMRAPI_Sample", MessageBoxButtons.OK, MessageBoxIcon.Information)
                GoTo Termination
            End If

            '// Barcode operation setting
            '// (Windows API manual 6.8.3.)
            bResponse = OMR_SetBarcodeReaderUnit(SR_ENABLE)
            If (1 <> bResponse) Then
                ErrorMessage("OMR_SetBarcodeReaderUnit", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Barcode area setting
            '// (Windows API manual 6.8.5.)
            bResponse = OMR_SetBarCodeArea(BarcodeArea(0))
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetBarCodeArea", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Barcode Reading type Setting
            '// (Windows API manual 6.8.7.)
            bResponse = OMR_SetBarCodeReadType(SR_BARCODE_READ_CODE39 Or SR_BARCODE_READ_ITF Or SR_BARCODE_READ_NW7 Or SR_BARCODE_READ_JAN_EAN_UPC)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetBarCodeReadType", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Barcode CheckDigit Setting
            '// (Windows API manual 6.8.9.)
            bResponse = OMR_SetBarCodeCheckDigit(SR_BARCODE_TYPE_CODE39, SR_BARCODE_CD.SR_BARCODE_CD_DISABLE)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetBarCodeCheckDigit", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Barcode Setting
            '// (Windows API manual 6.8.11.)
            bResponse = OMR_SetBarCodeOption(SR_BARCODE_TYPE_JAN_EAN_UPC, SR_BARCODE_OPT_UPC_13DIGIT Or SR_BARCODE_OPT_UPC_ADD_CODE)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetBarCodeOption", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If
        End If

        '//--------------------------------------------------------
        '//  Printer Setting
        '//--------------------------------------------------------

        '// [CAUTION]
        '// DipSW "SW3-3" is ON while use Printer function SR-1800PR.
        '// (See the user manual)
        '// (Factory default of "SW3-3" is "ON" by SR-1800PR)

        '// If check [Print], then execute Printer unit
        If (True = bPrintCheck) Then
            '// Printer would active in case connect printer unit or Select stacker
            If ((SR_DEVICE_UNIT_PRINTER <> (dwDeviceInfo And SR_DEVICE_UNIT_PRINTER_MASK)) And _
                (SR_DEVICE_UNIT_STACKER <> (dwDeviceInfo And SR_DEVICE_UNIT_STACKER_MASK))) Then
                MessageBox.Show("Printer unit unconnected", "OMRAPI_Sample", MessageBoxButtons.OK, MessageBoxIcon.Information)
                GoTo Termination
            End If

            '// Setting Priner Operation
            '// (Windows API manual 6.7.1.)
            bResponse = OMR_SetPrinterUnit(SR_ENABLE)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrinterUnit", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Print Mode
            '// (Windows API manual 6.7.5.)
            bResponse = OMR_SetPrintMode(SR_PRINT_MODE_FEED_AND_PRINT)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintMode", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Print Position
            '// (Windows API manual 6.7.7.)
            bResponse = OMR_SetPrintPosition(0)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintPosition", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Print Direction
            '// (Windows API manual 6.7.9.)
            bResponse = OMR_SetPrintAngle(SR_PRINT_ANGLE_0)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintAngle", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Print Size
            '// (Windows API manual 6.7.11.)
            bResponse = OMR_SetPrintFontSize(32)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintFontSize", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Print Pitch
            '// (Windows API manual 6.7.13.)
            bResponse = OMR_SetPrintFontPitch(8)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintFontPitch", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting Printer
            '// (Windows API manual 6.7.15.)
            bResponse = OMR_SetPrintString(1, "SEKONIC ")
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            bResponse = OMR_SetPrintString(2, "PRINT ")
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            bResponse = OMR_SetPrintString(3, "SANPLE ")
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

            '// Setting print order
            '// (Windows API manual 6.7.3.)
            bResponse = OMR_SetPrintOrder(SR_PRINT.SR_PRINT_BUFFER_1, SR_PRINT.SR_PRINT_BUFFER_2, SR_PRINT.SR_PRINT_BUFFER_3)
            If (True <> bResponse) Then
                ErrorMessage("OMR_SetPrintOrder", CUInt(OMR_GetLastError()))
                GoTo Termination
            End If

        End If

        '// Preprocessing roop
        Me.RICH_TEXT_BOX.Text = ""                  '// Clear RichTextBox

        '// Continue rooping till hopper empty or error happen
        Do While True

            strTextBuffer = ""                      '// Clear TXT buffer

            GetFilePath(strFolderPath, strTime)     '// Get fullpath of file and time 

            strTextBuffer += String.Format("[Data_{0}.csv]", strTime) + vbCrLf  '// Store the output data

            '//--------------------------------------------------------
            '//  Reading
            '//--------------------------------------------------------

            '// Mark reading
            bResponse = OMR_FeedSheet()
            If (OMR_STATUS.SR_SUCCESS <> CLng(OMR_GetLastError()) And (OMR_STATUS.SR_ERROR_STATUS_Q1 = CLng(OMR_GetLastError()))) Then
                MsgBox("Hopper Empty", vbInformation, "OMRAPI_Sample")
                Exit Do
            ElseIf (OMR_STATUS.SR_SUCCESS <> CLng(OMR_GetLastError())) Then
                Call ErrorMessage("OMR_FeedSheet", CLng(OMR_GetLastError()))
                Exit Do
            End If

            '//--------------------------------------------------------
            '//  Output mark data
            '//--------------------------------------------------------

            MarkInfo.columns = SR_COL_MAX          '// Initialize MarkInfo
            MarkInfo.rows = SR_ROW_MAX             '// Initialize MarkInfo

            '// Output mark data(front)
            strTextBuffer = strTextBuffer & "[Front MarkData]" & vbCrLf

            dwStatus = OMR_GetMarks(SR_PAGE.SR_PAGE_FRONT, MarkInfo, bytMarks(0))
            If (True <> bResponse) Then
                Call ErrorMessage("OMR_GetMarks", dwStatus)
                Exit Do
            End If

            strTextBuffer = strTextBuffer & OutputMarkData(MarkInfo, bytMarks)       '// Store mark data to buffer

            '// If "Installed backside read unit" or "valid back side reading",
            '// Output mark data(back)
            If ((SR_DEVICE_UNIT_BACK = (dwDeviceInfo And SR_DEVICE_UNIT_BACK_MASK)) And (SR_ENABLE = nDirective)) Then
                strTextBuffer = strTextBuffer & "[Back MarkData]" & vbCrLf
                dwStatus = OMR_GetMarks(SR_PAGE.SR_PAGE_BACK, MarkInfo, bytMarks(0))
                If (True <> bResponse) Then
                    Call ErrorMessage("OMR_GetMarks", dwStatus)
                    GoTo Termination
                End If
                strTextBuffer = strTextBuffer & OutputMarkData(MarkInfo, bytMarks)   '// Store mark data to buffer
            End If
            '//--------------------------------------------------------
            '//  Output Barcode data
            '//--------------------------------------------------------

            If (True = bBarcodeCheck) Then
                '// Get the number of barcode
                bResponse = OMR_GetBarcodeInfo(nReadCount, nSettingCount)
                If (True <> bResponse) Then
                    ErrorMessage("OMR_GetBarcodeInfo", CUInt(OMR_GetLastError()))
                    Exit Do
                End If

                strTextBuffer += String.Format("[BarcodeData],ReadingCount,{0:00}", nReadCount) + vbCrLf   '// Output the number of barcode read

                If (0 = nReadCount) Then    '// Not output Barcode data in case no read the barcode
                    GoTo BreakOutputBarcodeData
                End If

                '// Output barcode data
                For i As Integer = 0 To nReadCount - 1
                    nBcDataLen(i) = 256       '// Set the number of bytes of barcode data
                    bResponse = OMR_GetBarcodeData((i + 1), sBcType(i), nBcDataLen(i), sBcData(i, 0))
                    If (True <> bResponse) Then
                        ErrorMessage("OMR_GetBarcodeData", CUInt(OMR_GetLastError()))
                        GoTo Termination
                    End If
                Next

                strTextBuffer += OutputBarcodeData(nReadCount, sBcData, sBcType, nBcDataLen) + vbCrLf '// Store barcode data to buffer
            End If


BreakOutputBarcodeData:
            '//--------------------------------------------------------
            '//  Printer Operation
            '//--------------------------------------------------------

            If (True = bPrintCheck) Then
                '// Setting Printer
                '// (Windows API manual 6.7.15.)
                bResponse = OMR_SetPrintString(1, "SEKONIC ")
                If (True <> bResponse) Then
                    ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                    Exit Do
                End If

                bResponse = OMR_SetPrintString(2, "PRINT ")
                If (True <> bResponse) Then
                    ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                    Exit Do
                End If

                bResponse = OMR_SetPrintString(3, "SANPLE ")
                If (True <> bResponse) Then
                    ErrorMessage("OMR_SetPrintString", CUInt(OMR_GetLastError()))
                    Exit Do
                End If

                '// Setting print order
                '// (Windows API manual 6.7.3.)
                bResponse = OMR_SetPrintOrder(SR_PRINT.SR_PRINT_BUFFER_1, SR_PRINT.SR_PRINT_BUFFER_2, SR_PRINT.SR_PRINT_BUFFER_3)
                If (True <> bResponse) Then
                    ErrorMessage("OMR_SetPrintOrder", CUInt(OMR_GetLastError()))
                    Exit Do
                End If
            End If

            '// Output the contents of TXT buffer to RichEditControl
            Me.RICH_TEXT_BOX.AppendText(strTextBuffer)

            '// Save TXT buffer to file
            '// Comment-out the following process if OMR operation is slow. 
            SaveTextBuffer(strTextBuffer, strTime, strFolderPath)

            Me.Refresh()      '// Update Window
        Loop

        '//--------------------------------------------------------
        '//  Finish
        '//--------------------------------------------------------

Termination:
        '// Close the device if open
        If (1 = nDevice) Then
            dwStatus = OMR_CloseDevice()
            If (OMR_STATUS.SR_SUCCESS <> dwStatus) Then
                Call ErrorMessage("OMR_CloseDevice", CLng(OMR_GetLastError()))
            End If
        End If
    End Sub

    Private Sub B_QUIT_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles B_QUIT.Click
        Dim iMessageID As Integer = 0       '// Return message box

        iMessageID = MessageBox.Show("Finish Sample program?", "OMRAPI_Sample", MessageBoxButtons.YesNo, MessageBoxIcon.Information)
        If (DialogResult.Yes = iMessageID) Then
            Me.Close()                      '// Finish Sample program
        End If
    End Sub

    '// String(format) display Error information
    Public Sub ErrorMessage(ByRef sFuncName As String, ByVal dwStatus As Integer)
        Dim strError As String

        strError = String.Format("{0} Error (0x{1:00000000})", sFuncName, Hex(dwStatus))
        MessageBox.Show(strError, "OMRAPI_Sample", MessageBoxButtons.OK, MessageBoxIcon.Information)
    End Sub

    '// Strings(Function) to output mark data
    Public Function OutputMarkData(ByVal MarkInfo As OMR_MARK_INFO, ByRef pszMarks() As Byte) As String

        Dim nMarkLevel As Integer               '// Parameter to store the mark level
        Dim strMarkData As String = Nothing     '// mark data

        '// Strings(function) of output mark data
        If (Nothing <> pszMarks(0) And 4 < MarkInfo.columns) Then
            '// Output the header of columns
            strMarkData = ("   ,")
            For nColPosition As Integer = 0 To MarkInfo.columns - 1
                strMarkData += String.Format("{0:00},", (nColPosition + 1))
            Next nColPosition

            strMarkData += vbCrLf

            '// Output Mark data and header of the number of Row
            For nRowPosition As Integer = 0 To MarkInfo.rows - 1
                strMarkData += String.Format("{0:000},", (nRowPosition + 1))
                For nColPosition As Integer = 0 To MarkInfo.columns - 1
                    nMarkLevel = pszMarks((nRowPosition * MarkInfo.columns) + nColPosition)
                    strMarkData += String.Format("{0:00},", nMarkLevel)
                Next nColPosition
                strMarkData += vbCrLf
            Next nRowPosition
        End If
        strMarkData += vbCrLf
        Return strMarkData
    End Function

    '// Strings(function) to make and output barcode
    Public Function OutputBarcodeData(ByRef nReadCount As Integer, ByRef sBcData(,) As Byte, ByVal sBcType() As Byte, ByVal nBcDataLen() As Integer) As String

        Dim strBcBuffer As String = Nothing         '// Buffer for imput data
        Dim strBcTypeString As String = Nothing     '// The string of Barcode type
        Dim strBcData As String                     '// TXT strings to store Barcode Data

        '// Output the barcode data read(MAX :10 barcodes)
        For i As Integer = 0 To (nReadCount - 1)
            strBcData = Nothing                     '// Initialize strBcData

            Select Case Chr(sBcType(i))

                Case "a"
                    strBcTypeString = "CODE-39"

                Case "b"
                    strBcTypeString = "ITF"

                Case "c"
                    strBcTypeString = "NW-7"

                Case "d"
                    strBcTypeString = "JAN/EAN/UPC"

                Case "e"
                    strBcTypeString = "CODE-128"

                Case "f"
                    strBcTypeString = "INDUSTRIAL 2OF5"

                Case "g"
                    strBcTypeString = "COOP 2OF5"

                Case "h"
                    strBcTypeString = "CODE-93"

                Case "@"
                Case Else
                    strBcTypeString = "UNKNOWN"

            End Select

            '// Conversion Barcode data(Byte array) to String array 
            For Length As Integer = 0 To nBcDataLen(i) - 1
                strBcData += Chr(sBcData(i, Length))
            Next Length

            strBcBuffer += String.Format("{0:00},{1,-15}:{2}", (i + 1), strBcTypeString, strBcData) + vbCrLf
        Next i
        Return strBcBuffer
    End Function

    '// Strings(function) to get file path and current time
    Public Sub GetFilePath(ByRef pstrFolderPath As String, ByRef pstrTime As String)
        Dim dtTime As DateTime = DateTime.Now

        pstrTime = dtTime.ToString("yyyyMMddHHmmssfff")                 '// Output current time to dtTime with designated strings
        pstrFolderPath = My.Application.Info.DirectoryPath.ToString()   '// Get the folder path of Executed file
    End Sub

    '// Output txt buffer by CSV file
    '// Need cszTime and szFullPath while set the filename
    Public Sub SaveTextBuffer(ByVal strTextBuffer As String, ByRef strTime As String, ByRef strFolderPath As String)
        Dim SWriter As System.IO.StreamWriter = Nothing
        Dim strDataFileName As String      '// File name of Data

        strDataFileName = strFolderPath + "\Data_" + strTime + ".csv"

        Try
            SWriter = New System.IO.StreamWriter(strDataFileName, True)
            SWriter.Write(strTextBuffer)
        Finally
            If Not (SWriter Is Nothing) Then
                SWriter.Close()
            End If
        End Try
    End Sub
End Class

'//=========================================================
'//	Sample Program End
'//=========================================================
