Option Explicit On
Imports System.Runtime.InteropServices
Public Module Omrapi
    '/*-----------------------------------------------------------------------------
    ' OMR API (omrapi.dll) Header

    ' Copyright 2002-2010 SEKONIC CORPORATION

    ' Version history
    ' ---------------------------------------------------------------------------
    '  date		version		notes
    ' ---------------------------------------------------------------------------
    '  2012.03.15	4.3.0		for New Sample Program.
    '  2010.10.08	4.2.0		SkCommIo.dll is used.

    '  2010.03.30	4.1.0		Minor fix.

    '  2009.05.13	4.0.0		add define MachineName

    '  2007.06.23	3.0.0		add Status code
    '					            SR_ERROR_STATUS_A8
    '					            SR_ERROR_STATUS_S3
    '					            SR_ERROR_STATUS_S4

    '  2004.05.18	2.5.0		add Printer Enabled function
    '  2003.10.15	2.4.0		modified Error Message
    '  2003.08.05	2.3.0		add Barcode function
    '				            add Sleep Mode function
    '  2003.01.31	2.2.0		add Printer function
    '  2002.12.06	2.1.0		release

    '  2002.08.20	1.0.0		first release

    '-----------------------------------------------------------------------------*/

    '/*-----------------------------------------------------------------------------
    'System Fixed Number
    '-----------------------------------------------------------------------------*/

    '/*-Status(OMR_STATUS)-------------------*/
    Public Enum OMR_STATUS As Integer
        SR_SUCCESS = 0
        SR_UNSUCCESSFUL
        SR_DISCONNECTED
        SR_WRONG_PARAMETER
        SR_MEMORY_ERROR
        SR_TIMEOUT
        SR_RECEIVE_NAK
        SR_WRONG_RESPONSE
        '/*
        'Status Error Information
        '  = &HXXXXXXXX
        ' ||||
        ' ||++------- :Page
        ' ||
        ' |+------ = &H0	:Main
        ' |        = &H1	:Sensor unit
        ' |        = &H2	:(reserved)
        ' |        = &H3	:Barcode reader unit
        ' |        = &H4	:Printer unit
        ' |        = &H5	:Stacker unit
        ' |        = &Hf	:other
        ' |
        ' +---- = &H0	:impossible to recovery(Hard error)
        '       = &H1	:Communication error
        '       = &H2	:Cover open error
        '       = &H3	:Jam error
        '       = &H4	:Warning
        '*/
        SR_ERROR_STATUS_A1 = &H10000
        SR_ERROR_STATUS_A2
        SR_ERROR_STATUS_A3
        SR_ERROR_STATUS_A4
        SR_ERROR_STATUS_A5
        SR_ERROR_STATUS_A6
        SR_ERROR_STATUS_A7                                      '/* Ver2.3.0	*/
        SR_ERROR_STATUS_A8                                      '/* Ver3.0.0	*/

        SR_ERROR_STATUS_B1F = &H1020000
        SR_ERROR_STATUS_B2F
        SR_ERROR_STATUS_B3F
        SR_ERROR_STATUS_B4F
        SR_ERROR_STATUS_B5F
        SR_ERROR_STATUS_B6F
        SR_ERROR_STATUS_B7F                                     '/* Ver2.3.0	*/

        SR_ERROR_STATUS_B1B = &H2020000
        SR_ERROR_STATUS_B2B
        SR_ERROR_STATUS_B3B
        SR_ERROR_STATUS_B4B
        SR_ERROR_STATUS_B5B
        SR_ERROR_STATUS_B6B
        SR_ERROR_STATUS_B7B                                     '/* Ver2.3.0	*/

        SR_ERROR_STATUS_C1 = &H3030000
        SR_ERROR_STATUS_C2
        SR_ERROR_STATUS_C3
        SR_ERROR_STATUS_C4
        SR_ERROR_STATUS_C5
        SR_ERROR_STATUS_C6
        SR_ERROR_STATUS_C7                                      '/* Ver2.3.0	*/

        SR_ERROR_STATUS_D1 = &H4040000
        SR_ERROR_STATUS_D2
        SR_ERROR_STATUS_D3
        SR_ERROR_STATUS_D4
        SR_ERROR_STATUS_D5
        SR_ERROR_STATUS_D6                                      '/* Ver2.3.0	*/

        SR_ERROR_STATUS_E1 = &H5050000
        SR_ERROR_STATUS_E2
        SR_ERROR_STATUS_E3
        SR_ERROR_STATUS_E4
        SR_ERROR_STATUS_E5
        SR_ERROR_STATUS_E6                                      '/* Ver2.3.0	*/

        SR_ERROR_STATUS_F1 = &H1F060000
        SR_ERROR_STATUS_F2
        SR_ERROR_STATUS_F3
        SR_ERROR_STATUS_F4
        SR_ERROR_STATUS_F5
        SR_ERROR_STATUS_F6
        SR_ERROR_STATUS_F7

        SR_ERROR_STATUS_G1 = &H20070000
        SR_ERROR_STATUS_G2 = &H25070001
        '//	SR_ERROR_STATUS_G3					= &H25070002		'/* Ver2.3.0	*/

        SR_ERROR_STATUS_H1 = &H30080000
        SR_ERROR_STATUS_H2
        SR_ERROR_STATUS_H3
        SR_ERROR_STATUS_H4

        SR_ERROR_STATUS_I1 = &H35090000
        SR_ERROR_STATUS_I2
        SR_ERROR_STATUS_I3
        '//	SR_ERROR_STATUS_I4										'/* Ver2.3.0	*/

        SR_ERROR_STATUS_P1 = &H42100000
        SR_ERROR_STATUS_P2 = &H43100001
        SR_ERROR_STATUS_P3 = &H44100002
        SR_ERROR_STATUS_P4 = &H45100003

        SR_ERROR_STATUS_Q1 = &H40110000
        SR_ERROR_STATUS_Q2
        SR_ERROR_STATUS_Q3
        SR_ERROR_STATUS_Q4

        SR_ERROR_STATUS_R1 = &H40120000
        SR_ERROR_STATUS_R2
        SR_ERROR_STATUS_R3

        SR_ERROR_STATUS_R4M = &H40120003
        SR_ERROR_STATUS_R4F = &H41120003
        SR_ERROR_STATUS_R4B = &H42120003

        SR_ERROR_STATUS_R5M = &H40120004
        SR_ERROR_STATUS_R5F = &H41120004
        SR_ERROR_STATUS_R5B = &H42120004

        SR_ERROR_STATUS_S1F = &H41130000
        SR_ERROR_STATUS_S2F
        SR_ERROR_STATUS_S1B = &H42130002
        SR_ERROR_STATUS_S2B
        SR_ERROR_STATUS_S3 = &H40130002        '/* Ver3.0.0	*/
        SR_ERROR_STATUS_S4 = &H40130003        '/* Ver3.0.0	*/

        SR_ERROR_STATUS_T1 = &H40140000
        SR_ERROR_STATUS_T2
        SR_ERROR_STATUS_T3

        SR_ERROR_STATUS_T4 = &H45140003
        SR_ERROR_STATUS_T5
        SR_ERROR_STATUS_T6

        SR_ERROR_TERM = &HFFFFFFFF
    End Enum


    '/*-Global Parameter---------------------*/
    Public Const SR_INITIAL = &H80000000
    Public Const SR_DISABLE = 0
    Public Const SR_ENABLE = 1

    Public Const SR_FUNCTION_FAIL = &HFFFFFFFF


    '/*-Language(iLanguageFlag)--------------*/
    Public Enum SR_STRING As Integer
        SR_STRING_NORMAL = 0
        SR_STRING_ENGLISH
        SR_STRING_JAPANESE
    End Enum


    '/*-Page(iPage)--------------------------*/
    Public Enum SR_PAGE As Integer
        SR_PAGE_FRONT = 0
        SR_PAGE_BACK
    End Enum
    Public Const SR_PAGE_MAX = 2


    '/*-Col Row------------------------------*/
    Public Const SR_COL_MAX = 48
    Public Const SR_ROW_MAX = 155


    '/*-Reading Method(iControlType)---------*/
    Public Enum SR_READ As Integer
        SR_READ_FRONT_EDGE = 1                          '/*	Front Edge control type	*/
        SR_READ_REAR_EDGE                               '/*	Rear Edge control type	*/
        SR_READ_DIRECT                                  '/*	Direct type	*/
        SR_READ_FACOM                                   '/*	FACOM type	*/
        SR_READ_BETWEEN_MARK_NO_SPACE                   '/*	Between mark and mark without front edge space	*/
        SR_READ_BETWEEN_MARK                            '/*	Between mark and mark	*/
        SR_READ_INITIAL = SR_INITIAL                    '/*	Initialize control type	*/
    End Enum


    '/*-Feed Mode(iMode)---------------------*/
    Public Const SR_MODE_AUTO = 0
    Public Const SR_MODE_MANUAL = 1


    '/*-Sheet thickness(iThickness)----------*/
    Public Enum SR_THICKNESS As Integer
        SR_THICKNESS_AUTO_DETECT = 0                    '/*	Auto			*/
        SR_THICKNESS_64_GPM2 = 1                        '/*	64g/m2  (55kg)	*/
        SR_THICKNESS_84_GPM2                            '/*	84g/m2  (72kg)	*/
        SR_THICKNESS_105_GPM2                           '/*	105g/m2 (90kg)	*/
        SR_THICKNESS_128_GPM2                           '/*	128g/m2 (110kg)	*/
        SR_THICKNESS_157_GPM2                           '/*	157g/m2 (135kg)	*/
        SR_THICKNESS_INITIAL = SR_INITIAL               '/*	initailze		*/

        SR_THICKNESS_80_MICRON = 1                      '/*	0.08mm (55kg)	*/
        SR_THICKNESS_110_MICRON                         '/*	0.11mm (72kg)	*/
        SR_THICKNESS_130_MICRON                         '/*	0.13mm (90kg)	*/
        SR_THICKNESS_160_MICRON                         '/*	0.16mm (110kg)	*/
        SR_THICKNESS_190_MICRON                         '/*	0.19mm (135kg)	*/

        SR_THICKNESS_55_KG = 1                          '/*	64g/m2  (55kg)	*/
        SR_THICKNESS_72_KG                              '/*	84g/m2  (72kg)	*/
        SR_THICKNESS_90_KG                              '/*	105g/m2 (90kg)	*/
        SR_THICKNESS_110_KG                             '/*	128g/m2 (110kg)	*/
        SR_THICKNESS_135_KG                             '/*	157g/m2 (135kg)	*/
    End Enum


    '/*-WarningError(dwConfigData)-----------*/
    Public Const SR_WARN_MARK_SKEW = &H200000
    Public Const SR_WARN_LEFT_SKEW = &H100000
    Public Const SR_WARN_DF_ERROR = &H80000
    Public Const SR_WARN_TM_ERROR = &H40000
    Public Const SR_WARN_HOPPER_EMPTY = &H20000
    Public Const SR_WARN_AUTO_REJECT = &H10000

    Public Const SR_WARN_NONE = &H0
    Public Const SR_WARN_ALL = &H3F0000
    Public Const SR_WARN_INITIAL = &H10000000


    '/*-Buzzer Volume(iVolume)---------------*/
    Public Const SR_BUZZER_DISABLE = 0                  '/* Buzzer Off			*/
    Public Const SR_BUZZER_MIN = 1                      '/* Buzzer Volume Min.	*/
    Public Const SR_BUZZER_MAX = 5                      '/* Buzzer Volume Max.	*/
    Public Const SR_BUZZER_INITIAL = SR_INITIAL


    '/*-Buzzer Tone(iTone)-------------------*/
    Public Enum SR_BUZZER
        SR_BUZZER_TONE_A = 1
        SR_BUZZER_TONE_B
        SR_BUZZER_TONE_C
    End Enum


    '/*-ID(pID)------------------------------*/
    Public Const SR_ID_LENGTH_MAX = 20


    '/*-SleepTime(iSleepTime)----------------*/
    Public Const SR_SLEEPTIME_INITIAL = SR_INITIAL
    Public Const SR_SLEEPTIME_DISABLE = 0
    Public Const SR_SLEEPTIME_MIN = 1
    Public Const SR_SLEEPTIME_MAX = 60
    Public Const SR_STANDBYTIME_DISABLE = 0
    Public Const SR_STANDBYTIME_MIN = 1
    Public Const SR_STANDBYTIME_MAX = 60


    '/*-Hopper(iDirection)-------------------*/
    Public Const SR_HOPPER_DOWN = 0
    Public Const SR_HOPPER_UP = 1


    '/*-Eject (iDirection)-------------------*/
    Public Enum SR_EJECT
        SR_EJECT_MAIN = 1
        SR_EJECT_SELECT
        SR_EJECT_MAIN_ON_NEXT
        SR_EJECT_SELECT_ON_NEXT
    End Enum


    '/*-Mark Type(OMR_MARK.type)-------------*/
    Public Const SR_MARK_TYPE_16 = 16
    Public Const SR_MARK_TYPE_256 = 256


    '/*-SensorInfo---------------------------*/
    Public Const SR_SENSOR_OUTPS = &H20000000
    Public Const SR_SENSOR_RDPS = &H10000000
    Public Const SR_SENSOR_INPS = &H8000000
    Public Const SR_SENSOR_PS0 = &H4000000
    Public Const SR_SENSOR_UPPS = &H2000000
    Public Const SR_SENSOR_DWPS = &H1000000
    Public Const SR_SENSOR_SKS = &H100000
    Public Const SR_SENSOR_MAIN_CVR = &H10000

    '/*Public Const	SR_SENSOR_SPS   = &H00000800*/	        '/* Ver2.3.0	*/
    '/*Public Const	SR_SENSOR_MPS   = &H00000400*/	        '/* Ver2.3.0	*/
    '/*Public Const	SR_SENSOR_P2PS	= &H00000200*/	        '/* Ver2.3.0	*/
    '/*Public Const	SR_SENSOR_STPS	= &H00000100*/	        '/* Ver2.3.0	*/
    Public Const SR_SENSOR_SPS = &H400                      '/* Ver2.3.0	*/
    Public Const SR_SENSOR_MPS = &H200                      '/* Ver2.3.0	*/
    Public Const SR_SENSOR_P2PS = &H100                     '/* Ver2.3.0	*/
    '/*Public Const	SR_SENSOR_STK_CVR2  = &H00000002*/	    '/* Ver2.3.0	*/
    Public Const SR_SENSOR_STK_CVR1 = &H1
    Public Const SR_SENSOR_STK_CVR = &H1                    '/* Ver2.3.0	*/


    '/*-DeviceInfo---------------------------*/
    Public Const SR_DEVICE_UNIT_STACKER_MASK = &HF0000000   '/* Ver2.3.0	*/
    Public Const SR_DEVICE_UNIT_STACKER = &H10000000
    Public Const SR_DEVICE_UNIT_STACKER_ERR = &H80000000
    Public Const SR_DEVICE_UNIT_PRINTER_MASK = &HF000000    '/* Ver2.3.0	*/
    Public Const SR_DEVICE_UNIT_PRINTER = &H1000000
    Public Const SR_DEVICE_UNIT_PRINTER_ERR = &H8000000
    Public Const SR_DEVICE_UNIT_BARCODE_MASK = &HF00000     '/* Ver2.3.0	*/
    Public Const SR_DEVICE_UNIT_BARCODE_V = &H100000
    Public Const SR_DEVICE_UNIT_BARCODE_H = &H200000
    Public Const SR_DEVICE_UNIT_BARCODE_ERR = &H800000
    Public Const SR_DEVICE_UNIT_BACK_MASK = &HF0000         '/* Ver2.3.0	*/
    Public Const SR_DEVICE_UNIT_BACK = &H10000
    Public Const SR_DEVICE_SENSOR_TYPE_MASK = &HF0          '/* Ver2.3.0	*/
    Public Const SR_DEVICE_SENSOR_TYPE_ERR = &H80           '/* Ver2.3.0	*/
    Public Const SR_DEVICE_SENSOR_PITCH_MASK = &HF
    Public Const SR_DEVICE_SENSOR_PITCH_ERR = &HF

    '/*-MachineName--------------------------*/
    Public Const SR_MACHINENAME_SR2300 = "SR-2300"          '/* Ver4.0.0	*/
    Public Const SR_MACHINENAME_SR5500 = "SR-5500"          '/* Ver4.0.0	*/
    Public Const SR_MACHINENAME_SR3500 = "SR-3500"          '/* Ver4.0.0	*/
    Public Const SR_MACHINENAME_SR6000 = "SR-6000"          '/* Ver4.0.0	*/
    Public Const SR_MACHINENAME_SR6500 = "SR-6500"          '/* Ver4.0.0	*/
    Public Const SR_MACHINENAME_SR1800 = "SR-1800"          '/* Ver4.0.0	*/


    '/*-Unit Name(iTarget)-------------------*/
    Public Enum SR_UNIT
        SR_UNIT_MAIN = 0                                    '/*	Main				*/
        SR_UNIT_FRONT                                       '/*	Front Sensor unit	*/
        SR_UNIT_BACK                                        '/*	Back Sendor unit	*/
        SR_UNIT_BARCODE                                     '/*	Barcode reader unit	*/
        SR_UNIT_PRINTER                                     '/*	Printer unit		*/
        SR_UNIT_STACKER                                     '/*	Stacker unit		*/
    End Enum


    '/*-Print Mode(iMode)--------------------*/
    Public Const SR_PRINT_MODE_AFTER_FEED = 1
    Public Const SR_PRINT_MODE_FEED_AND_PRINT = 2


    '/*-Print buffer(iBufDirec)--------------*/
    Public Enum SR_PRINT
        SR_PRINT_BUFFER_NULL = 0
        SR_PRINT_BUFFER_1
        SR_PRINT_BUFFER_2
        SR_PRINT_BUFFER_3
    End Enum


    '/*-Print Buffer Size--------------------*/
    Public Const SR_PRINT_BUFFER_LENGTH_MAX = 42


    '/*-Print Angle(dwAngle)-----------------*/
    Public Const SR_PRINT_ANGLE_0 = 1
    Public Const SR_PRINT_ANGLE_180 = 2


    '/*-BarcodeData--------------------------*/             '/* Ver2.3.0	        */
    Public Const SR_BARCODE_NUMBER_MAX = 10


    '/*-Barcode Type(pBcType)----------------*/             '/* Ver2.3.0	        */
    Public Const SR_BARCODE_TYPE_UNKNOWN = "@"              '/* unknown				*/
    Public Const SR_BARCODE_TYPE_CODE39 = "a"               '/* CODE-39				*/
    Public Const SR_BARCODE_TYPE_ITF = "b"                  '/* ITF					*/
    Public Const SR_BARCODE_TYPE_NW7 = "c"                  '/* NW-7				*/
    Public Const SR_BARCODE_TYPE_JAN_EAN_UPC = "d"          '/* JAN/EAN/UPC			*/
    Public Const SR_BARCODE_TYPE_CODE128 = "e"              '/* CODE-128			*/
    Public Const SR_BARCODE_TYPE_INDUSTRIAL2OF5 = "f"       '/* Industrial 2of5		*/
    Public Const SR_BARCODE_TYPE_COOP2OF5 = "g"             '/* COOP 2of5			*/
    Public Const SR_BARCODE_TYPE_CODE93 = "h"               '/* CODE-93				*/

    '/*-Read Barcode Type(pBcTypes)----------*/             '/* Ver2.3.0	        */
    Public Const SR_BARCODE_READ_INITIAL = SR_INITIAL       '/* Initial				*/
    Public Const SR_BARCODE_READ_CODE39 = &H1               '/* CODE-39				*/
    Public Const SR_BARCODE_READ_ITF = &H2                  '/* ITF					*/
    Public Const SR_BARCODE_READ_NW7 = &H4                  '/* NW-7				*/
    Public Const SR_BARCODE_READ_JAN_EAN_UPC = &H8          '/* JAN/EAN/UPC			*/
    Public Const SR_BARCODE_READ_CODE128 = &H10             '/* CODE-128			*/
    Public Const SR_BARCODE_READ_INDUSTRIAL2OF5 = &H20      '/* Industrial 2of5		*/
    Public Const SR_BARCODE_READ_COOP2OF5 = &H40            '/* COOP 2of5			*/
    Public Const SR_BARCODE_READ_CODE93 = &H80              '/* CODE-93				*/

    '/*-Barcode CD Type(pCdType)-------------*/             '/* Ver2.3.0	        */
    Public Enum SR_BARCODE_CD
        SR_BARCODE_CD_INITIAL = SR_INITIAL
        SR_BARCODE_CD_DISABLE = 0
        SR_BARCODE_CD_ENABLE = 1
        SR_BARCODE_CD_MODULO16 = 1                          '/* Modulo 16			*/
        SR_BARCODE_CD_MODULO11                              '/* Modulo 11			*/
        SR_BARCODE_CD_MODULO10WAIT2                         '/* Modulo 10 Wait 2	*/
        SR_BARCODE_CD_MODULO10WAIT3                         '/* Modulo 10 Wait 3	*/
        SR_BARCODE_CD_7DR                                   '/* 7 DR				*/
        SR_BARCODE_CD_MODULO11W                             '/* Modulo 11 Weighted	*/
        SR_BARCODE_CD_RUNES                                 '/* Runes				*/
    End Enum

    '/*-Barcode UPC Option(dwOption)---------*/             '/* Ver2.3.0	        */
    Public Const SR_BARCODE_OPT_INITIAL = &HFFFFFFFF        '/* initial				*/
    Public Const SR_BARCODE_OPT_PARAM1_MASK = &HF           '/* Param 1				*/
    Public Const SR_BARCODE_OPT_UPC_12DIGIT = &H1           '/* UPC-A 12Digit		*/
    Public Const SR_BARCODE_OPT_UPC_13DIGIT = &H2           '/* UPC-A 13Digit		*/
    Public Const SR_BARCODE_OPT_PARAM2_MASK = &HF0          '/* Param 2				*/
    Public Const SR_BARCODE_OPT_UPC_NO_CODE = &H10          '/* UPC-E no system code*/
    Public Const SR_BARCODE_OPT_UPC_ADD_CODE = &H20         '/* UPC-E add system code*/


    '/*-----------------------------------------------------------------------------
    'Form and Mark Field structures
    '-----------------------------------------------------------------------------*/

    Public Structure OMR_MARK_INFO
        Public type As Integer
        Public rows As Integer
        Public columns As Integer
    End Structure

    Public Structure OMR_BARCODE_AREA
        Public unread As Integer
        Public read As Integer
    End Structure


    '/*-----------------------------------------------------------------------------
    'OMR API functions
    '-----------------------------------------------------------------------------*/

    '/*-USB Port Functions-------------------*/
    Public Declare Function OMR_OpenDeviceUSB Lib "OMRAPI.dll" () As UInteger

    '/*-other--------------------------------*/
    Public Declare Function OMR_CloseDevice Lib "OMRAPI.dll" () As UInteger
    Public Declare Function OMR_GetLastError Lib "OMRAPI.dll" () As UInteger
    Public Declare Function OMR_FormatMessage Lib "OMRAPI.dll" (ByVal status As UInteger, ByVal iLanguage As Integer) As Byte
    Public Declare Function OMR_GetST Lib "OMRAPI.dll" (ByVal iPage As Integer) As Byte

    '/*-Commands-----------------------------*/
    '/*-Settings-----------------------------*/
    Public Declare Function OMR_SetNumberOfColumnsToRead Lib "OMRAPI.dll" (ByVal iColumns As Integer) As Integer
    Public Declare Function OMR_GetNumberOfColumnsToRead Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetReadingMethod Lib "OMRAPI.dll" (ByVal iControlType As Integer, ByVal iMultipleValue As Integer) As Integer
    Public Declare Function OMR_GetReadingMethod Lib "OMRAPI.dll" (ByRef iControlType As Integer, ByRef iMultipleValue As Integer) As Integer
    Public Declare Function OMR_SetBackSensorUnit Lib "OMRAPI.dll" (ByVal iDirective As Integer) As Integer
    Public Declare Function OMR_GetBackSensorUnit Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetSheetFeedMode Lib "OMRAPI.dll" (ByVal iMode As Integer, ByVal iInsertTime As Integer) As Integer
    Public Declare Function OMR_GetSheetFeedMode Lib "OMRAPI.dll" (ByRef iMode As Integer, ByRef iInsertTime As Integer) As Integer
    Public Declare Function OMR_SetSheetThickness Lib "OMRAPI.dll" (ByVal iThickness As Integer) As Integer
    Public Declare Function OMR_GetSheetThickness Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetWarningError Lib "OMRAPI.dll" (ByVal dwConfigData As UInteger, ByVal iSkewCol As Integer, ByVal iSkewLevel As Integer) As Integer
    Public Declare Function OMR_GetWarningError Lib "OMRAPI.dll" (ByRef dwConfigData As UInteger, ByRef iSkewCol As Integer, ByRef iSkewLevel As Integer) As Integer
    Public Declare Function OMR_SetPanelConfig Lib "OMRAPI.dll" (ByVal iPanelEnable As Integer) As Integer
    Public Declare Function OMR_GetPanelConfig Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetBuzzerConfig Lib "OMRAPI.dll" (ByVal iVolume As Integer, ByVal iTone As Integer) As Integer
    Public Declare Function OMR_GetBuzzerConfig Lib "OMRAPI.dll" (ByRef iVolume As Integer, ByRef iTone As Integer) As Integer
    Public Declare Function OMR_SetID Lib "OMRAPI.dll" (ByRef pID As Byte) As Integer
    Public Declare Function OMR_GetID Lib "OMRAPI.dll" (ByRef pID As Byte) As Integer
    Public Declare Function OMR_SetSleepTime Lib "OMRAPI.dll" (ByVal iSleepTime As Integer, ByVal iStandbyTime As Integer) As Integer
    Public Declare Function OMR_GetSleepTime Lib "OMRAPI.dll" (ByRef iSleepTime As Integer, ByRef iStandbyTime As Integer) As Integer

    '/*-movement request---------------------*/
    Public Declare Function OMR_Reset Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_FeedSheet Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_MoveHopper Lib "OMRAPI.dll" (ByVal iDirection As Integer) As Integer
    Public Declare Function OMR_EjectSheet Lib "OMRAPI.dll" (ByVal iDirection As Integer) As Integer
    Public Declare Function OMR_InitialSetting Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_CancelError Lib "OMRAPI.dll" () As UInteger

    '/*-deta request-------------------------*/
    Public Declare Function OMR_GetMarks Lib "OMRAPI.dll" (ByVal iPage As Integer, ByRef MarkInfo As OMR_MARK_INFO, ByRef MarkArray As Byte) As Integer
    Public Declare Function OMR_GetStatus Lib "OMRAPI.dll" () As UInteger
    Public Declare Function OMR_GetSensorInfo Lib "OMRAPI.dll" () As UInteger
    Public Declare Function OMR_GetDeviceInfo Lib "OMRAPI.dll" () As UInteger
    Public Declare Function OMR_GetMachineName Lib "OMRAPI.dll" (ByRef pResult As Byte) As Integer
    Public Declare Function OMR_GetVersion Lib "OMRAPI.dll" (ByVal iTarget As Integer, ByRef pResult As Byte) As Integer

    '/*-printer settings---------------------*/
    Public Declare Function OMR_SetPrinterUnit Lib "OMRAPI.dll" (ByVal iDirective As Integer) As Integer
    Public Declare Function OMR_GetPrinterUnit Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetPrintOrder Lib "OMRAPI.dll" (ByVal iFirst As Integer, ByVal iSecond As Integer, ByVal iThird As Integer) As Integer
    Public Declare Function OMR_GetPrintOrder Lib "OMRAPI.dll" (ByRef iFirst As Integer, ByRef iSecond As Integer, ByRef iThird As Integer) As Integer
    Public Declare Function OMR_SetPrintMode Lib "OMRAPI.dll" (ByVal iMode As Integer) As Integer
    Public Declare Function OMR_GetPrintMode Lib "OMRAPI.dll" (ByRef piMode As Integer) As Integer
    Public Declare Function OMR_SetPrintPosition Lib "OMRAPI.dll" (ByVal iPosition As UInteger) As Integer
    Public Declare Function OMR_GetPrintPosition Lib "OMRAPI.dll" (ByRef iPosition As Integer) As UInteger
    Public Declare Function OMR_SetPrintAngle Lib "OMRAPI.dll" (ByVal dwAngle As UInteger) As Integer
    Public Declare Function OMR_GetPrintAngle Lib "OMRAPI.dll" (ByRef dwAngle As UInteger) As UInteger
    Public Declare Function OMR_SetPrintFontSize Lib "OMRAPI.dll" (ByVal iSize As Integer) As Integer
    Public Declare Function OMR_GetPrintFontSize Lib "OMRAPI.dll" (ByRef iSize As Integer) As Integer
    Public Declare Function OMR_SetPrintFontPitch Lib "OMRAPI.dll" (ByVal iPitch As Integer) As Integer
    Public Declare Function OMR_GetPrintFontPitch Lib "OMRAPI.dll" (ByRef iPitch As Integer) As Integer
    Public Declare Function OMR_SetPrintString Lib "OMRAPI.dll" (ByVal iBufDirec As Integer, ByVal pString As String) As Integer
    Public Declare Function OMR_GetPrintString Lib "OMRAPI.dll" (ByVal iBufDirec As Integer, ByVal pString As String) As Integer

    '/*-Barcode------------------------------*/
    Public Declare Function OMR_GetBarcodeInfo Lib "OMRAPI.dll" (ByRef piReadCount As Integer, ByRef piSettingCount As Integer) As Integer
    Public Declare Function OMR_GetBarcodeData Lib "OMRAPI.dll" (ByVal iIndex As Integer, ByRef pBcType As Byte, ByRef piDataLen As Integer, ByRef pBarcode As Byte) As Integer
    Public Declare Function OMR_SetBarcodeReaderUnit Lib "OMRAPI.dll" (ByVal iDirective As Integer) As Integer
    Public Declare Function OMR_GetBarcodeReaderUnit Lib "OMRAPI.dll" () As Integer
    Public Declare Function OMR_SetBarCodeArea Lib "OMRAPI.dll" (ByRef pAreaArray As OMR_BARCODE_AREA) As Integer
    Public Declare Function OMR_GetBarCodeArea Lib "OMRAPI.dll" (ByRef pAreaArray As OMR_BARCODE_AREA) As Integer
    Public Declare Function OMR_SetBarCodeReadType Lib "OMRAPI.dll" (ByVal dwReadType As UInteger) As Integer
    Public Declare Function OMR_GetBarCodeReadType Lib "OMRAPI.dll" (ByRef pdwReadType As UInteger) As Integer
    Public Declare Function OMR_SetBarCodeCheckDigit Lib "OMRAPI.dll" (ByVal cBcType As Char, ByVal iCdType As Integer) As Integer
    Public Declare Function OMR_GetBarCodeCheckDigit Lib "OMRAPI.dll" (ByVal cBcType As Char, ByRef iCdType As Integer) As Integer
    Public Declare Function OMR_SetBarCodeOption Lib "OMRAPI.dll" (ByVal cBcType As Char, ByVal dwOption As UInteger) As Integer
    Public Declare Function OMR_GetBarCodeOption Lib "OMRAPI.dll" (ByVal cBcType As Char, ByRef dwOption As UInteger) As Integer

End Module
